summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJim Meyering <jim@meyering.net>1995-08-07 16:06:43 +0000
committerJim Meyering <jim@meyering.net>1995-08-07 16:06:43 +0000
commit9c3f1711e250d6e1fc547702c5ab1bf94bbcea6a (patch)
treec9a1e8da9e56eeeac1f3ffe15c31f75abf9e1e4d
parent0347634ad3ddea082500b998e9af9445f6dd786d (diff)
downloadcoreutils-9c3f1711e250d6e1fc547702c5ab1bf94bbcea6a.tar.xz
(is_number): Rename from isnumber.
-rw-r--r--src/spline.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/spline.c b/src/spline.c
index fb6a8627a..4ce9e0366 100644
--- a/src/spline.c
+++ b/src/spline.c
@@ -394,8 +394,8 @@ char *str;
++s;
type = OPTION;
}
- else if (isnumber(s)) {
- while (isnumber(s))
+ else if (is_number(s)) {
+ while (is_number(s))
*str++ = *s++;
*str = '\0';
type = NUMBER;
@@ -409,8 +409,8 @@ char *str;
return(type);
}
-/* isnumber -- Return TRUE if argument is the ASCII representation of a number. */
-isnumber(string)
+/* is_number -- Return TRUE if argument is the ASCII representation of a number. */
+is_number(string)
char *string;
{
if (isdigit(*string) ||